@@ -16,7 +16,7 @@ def test_grab_monitor(sct):
         assert isinstance(image.rgb, bytes)
 
 
-def test_grab_part_of_screen(sct):
+def test_grab_part_of_screen(sct, pixel_ratio):
     monitor = {"top": 160, "left": 160, "width": 160, "height": 160}
     image = sct.grab(monitor)
     assert isinstance(image, ScreenShot)
@@ -24,11 +24,11 @@ def test_grab_part_of_screen(sct):
     assert isinstance(image.rgb, bytes)
     assert image.top == 160
     assert image.left == 160
-    assert image.width == 160
-    assert image.height == 160
+    assert image.width == 160 * pixel_ratio
+    assert image.height == 160 * pixel_ratio
 
 
-def test_grab_part_of_screen_rounded(sct):
+def test_grab_part_of_screen_rounded(sct, pixel_ratio):
     monitor = {"top": 160, "left": 160, "width": 161, "height": 159}
     image = sct.grab(monitor)
     assert isinstance(image, ScreenShot)
@@ -36,8 +36,8 @@ def test_grab_part_of_screen_rounded(sct):
     assert isinstance(image.rgb, bytes)
     assert image.top == 160
     assert image.left == 160
-    assert image.width == 161
-    assert image.height == 159
+    assert image.width == 161 * pixel_ratio
+    assert image.height == 159 * pixel_ratio
 
 
 def test_grab_individual_pixels(sct):
