@@ -37,14 +37,15 @@ def test_factory_systems(monkeypatch):
 
     # macOS
     monkeypatch.setattr(platform, "system", lambda: "Darwin")
-    with pytest.raises(ScreenShotError):
+    with pytest.raises((ScreenShotError, ValueError)):
+        # ValueError on macOS Big Sur
         mss.mss()
     monkeypatch.undo()
 
     # Windows
     monkeypatch.setattr(platform, "system", lambda: "wInDoWs")
-    with pytest.raises(ValueError):
-        # wintypes.py:19: ValueError: _type_ 'v' not supported
+    with pytest.raises(ImportError):
+        # ImportError: cannot import name 'WINFUNCTYPE'
         mss.mss()
 
 
