@@ -6,6 +6,7 @@ Source: https://github.com/BoboTiG/python-mss
 import sys
 import ctypes
 import threading
+from ctypes import POINTER, Structure, WINFUNCTYPE, c_void_p
 from ctypes.wintypes import (
     BOOL,
     DOUBLE,
@@ -40,7 +41,7 @@ DIB_RGB_COLORS = 0
 SRCCOPY = 0x00CC0020
 
 
-class BITMAPINFOHEADER(ctypes.Structure):
+class BITMAPINFOHEADER(Structure):
     """ Information about the dimensions and color format of a DIB. """
 
     _fields_ = [
@@ -58,7 +59,7 @@ class BITMAPINFOHEADER(ctypes.Structure):
     ]
 
 
-class BITMAPINFO(ctypes.Structure):
+class BITMAPINFO(Structure):
     """
     Structure that defines the dimensions and color information for a DIB.
     """
@@ -66,10 +67,39 @@ class BITMAPINFO(ctypes.Structure):
     _fields_ = [("bmiHeader", BITMAPINFOHEADER), ("bmiColors", DWORD * 3)]
 
 
+MONITORNUMPROC = WINFUNCTYPE(INT, DWORD, DWORD, POINTER(RECT), DOUBLE)
+
+
+# C functions that will be initialised later.
+#
+# This is a dict:
+#    cfunction: (attr, argtypes, restype)
+#
+# Available attr: gdi32, user32.
+#
+# Note: keep it sorted by cfunction.
+CFUNCTIONS = {
+    "BitBlt": ("gdi32", [HDC, INT, INT, INT, INT, HDC, INT, INT, DWORD], BOOL),
+    "CreateCompatibleBitmap": ("gdi32", [HDC, INT, INT], HBITMAP),
+    "CreateCompatibleDC": ("gdi32", [HDC], HDC),
+    "DeleteObject": ("gdi32", [HGDIOBJ], INT),
+    "EnumDisplayMonitors": ("user32", [HDC, c_void_p, MONITORNUMPROC, LPARAM], BOOL),
+    "GetDeviceCaps": ("gdi32", [HWND, INT], INT),
+    "GetDIBits": (
+        "gdi32",
+        [HDC, HBITMAP, UINT, UINT, c_void_p, POINTER(BITMAPINFO), UINT],
+        BOOL,
+    ),
+    "GetSystemMetrics": ("user32", [INT], INT),
+    "GetWindowDC": ("user32", [HWND], HDC),
+    "SelectObject": ("gdi32", [HDC, HGDIOBJ], HGDIOBJ),
+}
+
+
 class MSS(MSSBase):
     """ Multiple ScreenShots implementation for Microsoft Windows. """
 
-    __slots__ = {"_bbox", "_bmi", "_data", "gdi32", "monitorenumproc", "user32"}
+    __slots__ = {"_bbox", "_bmi", "_data", "gdi32", "user32"}
 
     # Class attributes instanced one time to prevent resource leaks.
     bmp = None
@@ -84,10 +114,6 @@ class MSS(MSSBase):
 
         super().__init__()
 
-        self.monitorenumproc = ctypes.WINFUNCTYPE(
-            INT, DWORD, DWORD, ctypes.POINTER(RECT), DOUBLE
-        )
-
         self.user32 = ctypes.WinDLL("user32")
         self.gdi32 = ctypes.WinDLL("gdi32")
         self._set_cfunctions()
@@ -112,55 +138,18 @@ class MSS(MSSBase):
     def _set_cfunctions(self):
         """ Set all ctypes functions and attach them to attributes. """
 
-        void = ctypes.c_void_p
-        pointer = ctypes.POINTER
-
-        self._cfactory(
-            attr=self.user32, func="GetSystemMetrics", argtypes=[INT], restype=INT
-        )
-        self._cfactory(
-            attr=self.user32,
-            func="EnumDisplayMonitors",
-            argtypes=[HDC, void, self.monitorenumproc, LPARAM],
-            restype=BOOL,
-        )
-        self._cfactory(
-            attr=self.user32, func="GetWindowDC", argtypes=[HWND], restype=HDC
-        )
-
-        self._cfactory(
-            attr=self.gdi32, func="GetDeviceCaps", argtypes=[HWND, INT], restype=INT
-        )
-        self._cfactory(
-            attr=self.gdi32, func="CreateCompatibleDC", argtypes=[HDC], restype=HDC
-        )
-        self._cfactory(
-            attr=self.gdi32,
-            func="CreateCompatibleBitmap",
-            argtypes=[HDC, INT, INT],
-            restype=HBITMAP,
-        )
-        self._cfactory(
-            attr=self.gdi32,
-            func="SelectObject",
-            argtypes=[HDC, HGDIOBJ],
-            restype=HGDIOBJ,
-        )
-        self._cfactory(
-            attr=self.gdi32,
-            func="BitBlt",
-            argtypes=[HDC, INT, INT, INT, INT, HDC, INT, INT, DWORD],
-            restype=BOOL,
-        )
-        self._cfactory(
-            attr=self.gdi32, func="DeleteObject", argtypes=[HGDIOBJ], restype=INT
-        )
-        self._cfactory(
-            attr=self.gdi32,
-            func="GetDIBits",
-            argtypes=[HDC, HBITMAP, UINT, UINT, void, pointer(BITMAPINFO), UINT],
-            restype=BOOL,
-        )
+        cfactory = self._cfactory
+        attrs = {
+            "gdi32": self.gdi32,
+            "user32": self.user32,
+        }
+        for func, (attr, argtypes, restype) in CFUNCTIONS.items():
+            cfactory(
+                attr=attrs[attr],
+                func=func,
+                argtypes=argtypes,
+                restype=restype,
+            )  # type: ignore
 
     def _set_dpi_awareness(self):
         """ Set DPI aware to capture full screen on Hi-DPI monitors. """
@@ -229,7 +218,7 @@ class MSS(MSSBase):
             )
             return 1
 
-        callback = self.monitorenumproc(_callback)
+        callback = MONITORNUMPROC(_callback)
         user32.EnumDisplayMonitors(0, 0, callback, 0)
 
     def _grab_impl(self, monitor):
